==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/single_window/translations/single_window_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Look</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>SingleWindow</source>
        <translation>Jedno okno</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Roster position</source>
        <translation>Umístění rozpisu služeb</translation>
    </message>
    <message>
        <source>Choose position of roster in Single Window mode</source>
        <translation>Vyberte místění rozpisu služeb v režimu jednoho okna</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Přepnout na předchozí kartu</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Přepnout na další kartu</translation>
    </message>
    <message>
        <source>Show/hide roster</source>
        <translation>Ukázat/Skrýt rozpis služeb</translation>
    </message>
    <message>
        <source>Switch focus between roster and tabs</source>
        <translation>Přepnout zaměření mezi rozpisem služeb a kartami</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Chování</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/single_window/translations/single_window_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Look</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>SingleWindow</source>
        <translation>Jedno okno</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Roster position</source>
        <translation>Umístění rozpisu služeb</translation>
    </message>
    <message>
        <source>Choose position of roster in Single Window mode</source>
        <translation>Vyberte místění rozpisu služeb v režimu jednoho okna</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Přepnout na předchozí kartu</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Přepnout na další kartu</translation>
    </message>
    <message>
        <source>Show/hide roster</source>
        <translation>Ukázat/Skrýt rozpis služeb</translation>
    </message>
    <message>
        <source>Switch focus between roster and tabs</source>
        <translation>Přepnout zaměření mezi rozpisem služeb a kartami</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Chování</translation>
    </message>
</context>
</TS>
